@@ -1,11 +1,11 @@
-/*  File inst/include/ergm_MHproposal.h in package ergm, part of the Statnet suite
- *  of packages for network analysis, https://statnet.org .
+/*  File inst/include/ergm_MHproposal.h in package ergm, part of the
+ *  Statnet suite of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  https://statnet.org/attribution
+ *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2020 Statnet Commons
+ *  Copyright 2003-2022 Statnet Commons
  */
 #ifndef _ERGM_MHPROPOSAL_H_
 #define _ERGM_MHPROPOSAL_H_
@@ -13,23 +13,6 @@
 #include "ergm_edgetree.h"
 #include "R_ext/Rdynload.h"
 
-typedef struct DegreeBoundstruct {
-  int attrcount;
-  int fBoundDegByAttr;
-  int *attribs;
-  int *maxout;
-  int *minout;
-  int *maxin;
-  int *minin;
-} DegreeBound;
-
-DegreeBound* DegreeBoundInitialize(int *attribs, int *maxout, int *maxin, 
-			   int *minout, int *minin, int condAllDegExact, 
-			   int attriblength, Network *nwp);
-
-void DegreeBoundDestroy(DegreeBound *bd);
-
-
 #define NO_EDGE       0x00 /*these four used in realocateWithReplacement */
 #define OLD_EDGE      0x01 
 #define NEW_EDGE      0x02 
@@ -71,55 +54,43 @@ void DegreeBoundDestroy(DegreeBound *bd);
 /* *** don't forget tail-> head */
 
 typedef struct MHProposalstruct {
-  void (*func)(struct MHProposalstruct*, Network*);
+  SEXP R;
+  void (*i_func)(struct MHProposalstruct*, Network*);
+  void (*p_func)(struct MHProposalstruct*, Network*);
+  void (*u_func)(Vertex tail, Vertex head, struct MHProposalstruct*, Network*, Rboolean);
+  void (*f_func)(struct MHProposalstruct*, Network*);
+  void (*x_func)(unsigned int type, void *data, struct MHProposalstruct*, Network*);
   Edge ntoggles;
   Vertex *toggletail;
   Vertex *togglehead;
   double logratio;
   int status;
-  DegreeBound *bd;
-  Network **discord;
   double *inputs; /* may be used if needed, ignored if not. */
+  int *iinputs; /* may be used if needed, ignored if not. */
+  void *storage;
+  void **aux_storage;
+  unsigned int n_aux;
+  unsigned int *aux_slots;
 } MHProposal;
 
 
-MHProposal *MHProposalInitialize(
-	     char *MHProposaltype, char *MHProposalpackage, 
-	     double *inputs,
-	     int fVerbose,
-	     Network *nwp, 
-	     int *attribs, int *maxout, int *maxin, 
-	     int *minout, int *minin, int condAllDegExact, 
-	     int attriblength);
+MHProposal *MHProposalInitialize(SEXP pR, Network *nwp, void **aux_storage);
 
-void MHProposalDestroy(MHProposal *MHp);
-
-int CheckTogglesValid(MHProposal *MHp, Network *nwp);
-int CheckConstrainedTogglesValid(MHProposal *MHp, Network *nwp);
-
-#define BD_LOOP(proc) BD_COND_LOOP({proc}, TRUE, 1)
-
-#define BD_COND_LOOP(proc, cond, tryfactor)				\
-  unsigned int trytoggle;						\
-  for(trytoggle = 0; trytoggle < MAX_TRIES*tryfactor; trytoggle++){	\
-    {proc}								\
-    if(cond) break;							\
-  }									\
-  if(trytoggle>=MAX_TRIES*tryfactor){					\
-    MHp->toggletail[0]=MH_FAILED;					\
-    MHp->togglehead[0]=MH_UNSUCCESSFUL;					\
-  }else	if(!CheckTogglesValid(MHp,nwp)){				\
-    MHp->toggletail[0]=MH_FAILED;					\
-    MHp->togglehead[0]=MH_CONSTRAINT;                                   \
-  }									
+void MHProposalDestroy(MHProposal *MHp, Network *nwp);
 
 /* Helper macros */
-#define MH_INPUTS MHp->inputs
+#define MH_DINPUTS MHp->inputs
+#define MH_INPUTS MH_DINPUTS
+#define MH_IINPUTS MHp->iinputs
 
 #define Mtail (MHp->toggletail)
 #define Mhead (MHp->togglehead)
 
-#define MH_P_FN(a) void (a) (MHProposal *MHp, Network *nwp)
+#define MH_I_FN(a) void a (MHProposal *MHp, Network *nwp)
+#define MH_U_FN(a) void a (Vertex tail, Vertex head, MHProposal *MHp, Network *nwp, Rboolean edgestate)
+#define MH_P_FN(a) void a (MHProposal *MHp, Network *nwp)
+#define MH_F_FN(a) void a (MHProposal *MHp, Network *nwp)
+#define MH_X_FN(a) void a (unsigned int type, void *data, MHProposal* MHp, Network* nwp)
 
 /* Implementation of TNT log ratio for the three cases.
    The parameters are as follows. Let 
